@@ -1,4 +1,6 @@
+#!/usr/bin/env python
 from IdentityService.service import IdentityService
+import os
 # import pytest
 
 # pytest
@@ -9,7 +11,9 @@ file_name_option = input(
     \n from default ("data_file.json) file name? (Y/N) ')
 if file_name_option.lower()=="y":
     data_file_name=input('Specify file name: ')
-    service = IdentityService(f'{data_file_name}.json')
+    data_file_name = data_file_name+'.json'
+    path_=os.path.join(os.getcwd(), data_file_name)
+    service = IdentityService(path_=path_)
 
 else: service = IdentityService()
 
@@ -23,6 +27,7 @@ def crucial_credentials():
     return username, password
 
 while True:
+    
     intro_choice=input('Do you want to authinticate user? (Y/N) ')
     if intro_choice.lower()=='y':
         auth=crucial_credentials()
